You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by vk...@apache.org on 2020/12/31 19:13:47 UTC

[ignite-3] branch main updated: IGNITE-13943 - Changed default REST port to 10300

This is an automated email from the ASF dual-hosted git repository.

vkulichenko pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/ignite-3.git


The following commit(s) were added to refs/heads/main by this push:
     new f3c3fa0  IGNITE-13943 - Changed default REST port to 10300
f3c3fa0 is described below

commit f3c3fa0d731e29ca64acf084e9dbce3a23ed6b60
Author: Valentin Kulichenko <va...@gmail.com>
AuthorDate: Thu Dec 31 11:13:25 2020 -0800

    IGNITE-13943 - Changed default REST port to 10300
---
 .../src/main/java/org/apache/ignite/cli/spec/ConfigCommandSpec.java   | 4 ++--
 .../src/main/java/org/apache/ignite/rest/RestModule.java              | 4 ++--
 modules/ignite-runner/src/main/resources/bootstrap-config.json        | 2 +-
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/spec/ConfigCommandSpec.java b/modules/cli/src/main/java/org/apache/ignite/cli/spec/ConfigCommandSpec.java
index 551dd47..566bfad 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/spec/ConfigCommandSpec.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/spec/ConfigCommandSpec.java
@@ -80,7 +80,7 @@ public class ConfigCommandSpec extends CategorySpec {
 
         int port() {
             if (endpoint == null)
-                return 8080;
+                return 10300;
 
             var hostPort = parse();
 
@@ -99,7 +99,7 @@ public class ConfigCommandSpec extends CategorySpec {
             var hostPort = endpoint.split(":");
             if (hostPort.length != 2)
                 throw new IgniteCLIException("Incorrect host:port pair provided " +
-                    "(example of valid value 'localhost:8080')");
+                    "(example of valid value 'localhost:10300')");
            return hostPort;
         }
     }
diff --git a/modules/ignite-runner/src/main/resources/bootstrap-config.json b/modules/ignite-runner/src/main/resources/bootstrap-config.json
index 3b29984..b9fd7a1 100644
--- a/modules/ignite-runner/src/main/resources/bootstrap-config.json
+++ b/modules/ignite-runner/src/main/resources/bootstrap-config.json
@@ -1 +1 @@
-{"local":{"rest":{"port":8080,"portRange":100},"baseline":{"autoAdjust":{"timeout":10000,"enabled":true}},"dataStorage": {"pageSize":4096,"storagePath":"db/data","walPath":"db/wal"}}}
\ No newline at end of file
+{"local":{"rest":{"port":10300,"portRange":100},"baseline":{"autoAdjust":{"timeout":10000,"enabled":true}},"dataStorage": {"pageSize":4096,"storagePath":"db/data","walPath":"db/wal"}}}
diff --git a/modules/ignite-runner/src/main/java/org/apache/ignite/rest/RestModule.java b/modules/ignite-runner/src/main/java/org/apache/ignite/rest/RestModule.java
index 4ce35ed..87fb2e6 100644
--- a/modules/ignite-runner/src/main/java/org/apache/ignite/rest/RestModule.java
+++ b/modules/ignite-runner/src/main/java/org/apache/ignite/rest/RestModule.java
@@ -34,12 +34,12 @@ import org.slf4j.Logger;
 /**
  * Rest module is responsible for starting a REST endpoints for accessing and managing configuration.
  *
  * It is started on port 8080 by default but it is possible to change this in configuration itself.
  * Refer to default config file in resources for the example.
  */
 public class RestModule {
     /** */
-    private static final int DFLT_PORT = 8080;
+    private static final int DFLT_PORT = 10300;
 
     /** */
     private static final String CONF_URL = "/management/v1/configuration/";
@@ -34,12 +34,12 @@ import org.slf4j.Logger;
  * Rest module is responsible for starting a REST endpoints for accessing and managing configuration.
  *
- * It is started on port 8080 by default but it is possible to change this in configuration itself.
+ * It is started on port 10300 by default but it is possible to change this in configuration itself.
  * Refer to default config file in resources for the example.
  */